# Pyonir Plugins

The plugin system currently supports the ability to install 3rd party python tools that extends
functionality of your pyonir application.

Plugins have two categories: File extensions and App extensions.

# File extensions

this type of plugin parses and modify file data

# App extensions

This type of plugin incudes new functionality to your pyonir application that can include additional
routes, resolvers, and file extenstions.

examples include:

- Shopping carts
- Admin dashboards